@@ -23,12 +23,18 @@
 #include <gtk/gtk.h>
 #include <glib-object.h>
 
+#define HANDY_USE_UNSTABLE_API
+#include <handy.h>
+
 G_BEGIN_DECLS
 
-GtkWidget   *cc_language_chooser_new          (GtkWidget   *parent);
-void         cc_language_chooser_clear_filter (GtkWidget   *chooser);
-const gchar *cc_language_chooser_get_language (GtkWidget   *chooser);
-void         cc_language_chooser_set_language (GtkWidget   *chooser,
-                                               const gchar *language);
+#define CC_TYPE_LANGUAGE_CHOOSER (cc_language_chooser_get_type ())
+G_DECLARE_FINAL_TYPE (CcLanguageChooser, cc_language_chooser, CC, LANGUAGE_CHOOSER, HdyDialog)
+
+CcLanguageChooser *cc_language_chooser_new          (void);
+void               cc_language_chooser_clear_filter (CcLanguageChooser *chooser);
+const gchar       *cc_language_chooser_get_language (CcLanguageChooser *chooser);
+void               cc_language_chooser_set_language (CcLanguageChooser *chooser,
+                                                     const gchar       *language);
 
 G_END_DECLS
